Stan Math Library: stan/math/rev/core/v_vari.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

v_vari.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_V_VARI_HPP
2 #define STAN_MATH_REV_CORE_V_VARI_HPP
3
4 #include <stan/math/rev/core/vari.hpp>
5
6 namespace stan {
7 namespace math {
8
9 class op_v_vari : public vari {
10 protected:
11 vari* avi_;
12 public:
13 op_v_vari(double f, vari* avi) :
14 vari(f),
15 avi_(avi) {
16 }
17 };
18
19 }
20 }
21 #endif
vari.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::vari
The variable implementation base class.
Definition: vari.hpp:30
stan::math::op_v_vari::avi_
vari * avi_
Definition: v_vari.hpp:11
stan::math::op_v_vari
Definition: v_vari.hpp:9
stan::math::op_v_vari::op_v_vari
op_v_vari(double f, vari *avi)
Definition: v_vari.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.